/*
 * $Id:   _252x32_noritake.h 2013-06-29 AM 3:06:01 ssk  $
 *
 * Designed for Noritake GU256x64-901A VFD on Atmels AVR MCUs
 *
 * Copyright (C) 2013  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/

/**
 * \mainpage
 *  
 * _252x32_noritake bitmap image
 * 
 * Generate Picture File by "TDF(The Dot Factory)" 
 * Pixel orientation per Byte: D0..D7 (LSB First)
 *
 * \author ssk.
*/
#include <avr/pgmspace.h>

uint8_t _252x32_noritake[] PROGMEM =
{
  0x00,0xfc,   //width  : 252
  0x00,0x20,   //Height : 32
	//                                                                                                                                                                                    ###                                                                      
	//                                                                                                                                                                  #####          #######                                                                     
	//                                                          #####                                                                                                  #######        #######                                                                      
	//                                                   ###########                                                                                                   #######        #######                                                                      
	//                                               #############                                                                                                     #######       #######                                                                       
	//                                              #########                                                                                                          ######        #######                                                                       
	//                                            ######                                                                                                               #####        ########                                                                       
	//                           ##              ####                                                                       ###                                         ###         #######                                                                        
	//                          ###             ###                                                                        ###                                                     ########                                                                        
	//                          ###            ##                                            ###                          ###                                                      ########                                                                        
	//                         ####           ##                                  ##        ####                          ###                                                    ###########                ####                                                   
	//                         ####          ##                                   ###    #########                       ###                                      ########    ###############   #######  ##########       ################     #######   ######### 
	//                        #####         ##                                    ##    #########                       ###                                       ########    ###############   ###################      #################     ####################
	//                       #  ###        ##                                             ###                           ###                                        #######       ########        #########  #######     ########   #######      ###################
	//                       #  ##        ##                                              ###                          ###                                        #######        #######         #######    #######     #######    #######      ########   ########
	//                      #  ###        #                                              ###                          ###                                         #######        #######        ########    #######    ########    #######     ########    ####### 
	//                     #   ###       #                                              ###                           ###                                        ########       ########        #######     #######    #######    #######      #######    ######## 
	//                    ##   ###      #       ######         ###   ##       ###       ###        ######            ### #####         ####                      #######        #######         #######     ######    ########    #######      #######    ######## 
	//                    #    ###     #      #####  ##       ###  ####      ###       ###       ####   #####       #####    ##       ######                     #######       ########        #######       #####    #######     ######      #######     #######  
	//                   #     ###    #      #####    #      ##########     ####      ###       ####     ###       ####       ##     ###   #                    ########       #######         #######        ###     #######    #######      #######    ########  
	//                  #      ###    #     ###  #    #     #####  ###     ####       ###      ###      ###        ###        ##    ###    #                    #######        #######        ########               ########    #######     #######     #######   
	//                 #       ##    #     ###    #  ##   ######   ###   #####       ###      ###       ##       ####         ##   ###    ##                   ########       ########        #######                #######    #######      #######    ########   
	//               ##       ###   #      ###    ########  ###    ###### ###       ###       ###      ###      #####        ###   ##     #       ###          #######        #######         #######               ########    #######      #######    ########   
	//              ##        ###  #      ###       ###    ###      ##    ###      ####      ###      ###      #####   ### ####   ###    #      ######         #######       ########        #######                #######    #######      #######     #######    
	//             ##         ### ##      ###       ##    ###            ###      ####      ####      ###     #####   ########    ##    #      #####          ########       ########        #######                #######    #######      #######    ########    
	//           ###          #####       ##       ###    ##            ###       ###      ####      ###     # ####   ###         ##   #      ###             #######        #######        #######                #######    #######       ######     ########    
	// #       ####           ####        ##      ###    ###            ###     #####     # ###     ###    ##  ###    ##          ####       ##              ########       ########        #######                #######    #######      #######    ########     
	//  ##########            ####        ##      ##    ###            ###     #  ##     #  ###    ####   #   ###     ##          ###       ##               ########       #######         #######                #######    #######      #######    ########     
	//  ########              ###          #    ###     ###             ##   ##   ###  ##    ##   # ### ##   ###      ###        ####     ##                 #########      ########        ######                 #################       ######      ########    
	//    ####                ##            #  ##      ###              ####       ####       ###    ###     ##         #######      #####                    ########       #######        ######                  ###############         #####      ########    
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x03, 0x07, 0x0E, 0x0E, 0x0E, 0x0C, 0x1C, 0x1C, 0x1C, 0x1C, 0x18, 0x18, 0x18, 0x38, 0x38, 0x30, 0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x7F, 0x7F, 0x7F, 0x7E, 0x7C, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x0F, 0x3F, 0x7F, 0x7F, 0x7F, 0xFF, 0xFE, 0xF0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x06, 0x08, 0x39, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x06, 0x0C, 0x18, 0x30, 0x60, 0xC0, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x38, 0x10, 0x00, 0x00, 0x00, 0x08, 0x19, 0x1F, 0x1F, 0x3E, 0x78, 0x78, 0x78, 0x18, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x0F, 0x1E, 0x7C, 0xF0, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1B, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x18, 0x3F, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xF8, 0xF8, 0x38, 0x18, 0x00, 0x00, 0x00, 0x19, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x0F, 0x0C, 0x1C, 0x18, 0x18, 0x3F, 0x3F, 0x3F, 0x3F, 0x1F, 0x1F, 0x1F, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x18, 0x18, 0x18, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x19, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x0F, 0x0E, 0x0C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x0E, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x02, 0x04, 0x08, 0x10, 0x60, 0xC0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF8, 0x00, 0x01, 0x02, 0x04, 0x18, 0x20, 0x40, 0x80, 0x01, 0x07, 0x0F, 0x1E, 0x38, 0x30, 0x70, 0x78, 0x66, 0x42, 0x43, 0x67, 0x3F, 0x02, 0x02, 0x02, 0x04, 0x05, 0x0F, 0x1F, 0x3E, 0x7C, 0x78, 0x50, 0x10, 0x3E, 0x3F, 0x7F, 0x72, 0x02, 0x02, 0x04, 0x07, 0x0F, 0x1F, 0x3C, 0x78, 0x70, 0x40, 0x00, 0x00, 0x01, 0x03, 0x07, 0x1F, 0x3C, 0xF8, 0xE0, 0xC0, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x1E, 0x38, 0x30, 0x70, 0x60, 0x40, 0x41, 0x43, 0x6F, 0x3E, 0x38, 0x30, 0x20, 0x00, 0x00, 0x01, 0x03, 0x07, 0x07, 0x1F, 0x3E, 0x78, 0xF0, 0xE1, 0xA1, 0x41, 0x40, 0x41, 0x41, 0x63, 0x3F, 0x1E, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x1C, 0x38, 0x70, 0x60, 0x61, 0x66, 0x3C, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x03, 0x03, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xF0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x0F, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xF8, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xE0, 0xF0, 0xF0, 0xF0, 0xE0, 0x80, 0x00, 0x03, 0x0F, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xF8, 0xC0, 0x00, 0x01, 0x07, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xF8, 0xC0, 0x00, 0x00, 0x00, 0x01, 0x0F, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xF0, 0xC0, 0x00, 0x00, 0x07, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xF0, 0xC0, 0x00, 
	0x20, 0x18, 0x18, 0x1C, 0x1C, 0x1C, 0x1C, 0x18, 0x38, 0x30, 0x70, 0x60, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0xFC, 0xF8, 0x70, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0xF8, 0x84, 0x00, 0x00, 0x04, 0x0C, 0x08, 0x38, 0x70, 0xE0, 0xC0, 0x00, 0x04, 0x1C, 0x3C, 0xF8, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x7C, 0xFC, 0xE4, 0x84, 0x00, 0x08, 0x08, 0x10, 0x20, 0x20, 0xF8, 0xFC, 0xEC, 0x84, 0x04, 0x08, 0x08, 0x10, 0x20, 0x40, 0xF0, 0xF8, 0xFC, 0x84, 0x04, 0x00, 0x08, 0x10, 0x38, 0x7C, 0xFC, 0xC4, 0x88, 0x08, 0x10, 0x20, 0x20, 0x4C, 0x9C, 0xF8, 0xF0, 0xE0, 0xC0, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xCC, 0x84, 0x84, 0x84, 0x84, 0x84, 0x04, 0x00, 0x00, 0x08, 0xF8, 0xF8, 0x38, 0x24, 0x04, 0x44, 0x84, 0x04, 0x08, 0x08, 0x10, 0x30, 0x60, 0xC0, 0xC0, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xEC, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7C, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xF0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0x8C, 0x0C, 0x0C, 0x0C, 0x7C, 0xFC, 0xFC, 0xFC, 0xFC, 0xF8, 0xF0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xF0, 0x80, 0x00, 0x00, 0x00, 0x30, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xCC, 0x00, 0x00, 0x00, 0x00, 
};

/*
 * EOF
 */