/*
 * $Id:   _misc_bitmaps.h 2013-10-05 AM 10:20:17 ssk  $
 *
 * Designed for Noritake GU256x64-901A VFD on Atmels AVR MCUs
 *
 * Copyright (C) 2013  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/

/**
 * \mainpage
 *  
 * _misc_bitmaps a miscellaneous bitmap collection
 * 
 * Generate Picture File by "TDF(The Dot Factory)" 
 * Pixel orientation per Byte: D0..D7 (LSB First)
 *
 * \author ssk.
*/
#include <avr/pgmspace.h>

uint8_t _16x16_browser[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//      ######     
	//    ## ## # ##   
	//   ## #  # # ##  
	//  ## #   #  # ## 
	//  #  #   #  #  # 
	// # # #   #   ## #
	// #  ##########  #
	// #   #   #   #  #
	// #   #   #   #  #
	// ##  #   #   # ##
	// # # #   #   ## #
	//  # ########## # 
	//  ##  #  #  # ## 
	//   ## #  # # ##  
	//    ## #### ##   
	//      ######     
	0x07, 0x18, 0x34, 0x62, 0x5F, 0xA2, 0xC2, 0xC2, 0xBF, 0xC2, 0xA2, 0x5A, 0x67, 0x34, 0x18, 0x07, 
	0xE0, 0x58, 0x2C, 0x16, 0xF2, 0x1D, 0x13, 0x13, 0xFF, 0x13, 0x15, 0x1A, 0xF6, 0x2C, 0x58, 0xE0, 
};
   
uint8_t _16x16_camera[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//         #####   
	//        #     #  
	//        #     #  
	//         #####   
	//  ####    # #    
	// ##  ########### 
	// #    #         #
	// #    #   ###   #
	// #    #  #   #  #
	// #    # # ### # #
	// #    # # ### # #
	// #    # # ### # #
	// #    #  #   #  #
	// #    #   ###   #
	// ##  ########### 
	//  ####           
	0x07, 0x0C, 0x08, 0x08, 0x0C, 0x07, 0x04, 0x64, 0x94, 0x9D, 0x95, 0x9D, 0x94, 0x64, 0x04, 0x03, 
	0xFE, 0x03, 0x01, 0x01, 0x03, 0xFE, 0x02, 0x72, 0x8A, 0x76, 0x76, 0x76, 0x8A, 0x72, 0x02, 0xFC, 
};

uint8_t _16x16_dictionary[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//  #####    ##### 
	// #     ####     #
	// #      ##      #
	// #      ##      #
	// # #### ## #### #
	// #      ##      #
	// #      ##      #
	// # #### ## #### #
	// #      ##      #
	// #      ##      #
	// # #### ## #### #
	// #      ##      #
	// #      ##      #
	// ###### ## ######
	// #     ####     #
	//  ######  ###### 
	0x7F, 0x80, 0x89, 0x89, 0x89, 0x89, 0x40, 0x7F, 0x7F, 0x40, 0x89, 0x89, 0x89, 0x89, 0x80, 0x7F, 
	0xFE, 0x05, 0x25, 0x25, 0x25, 0x25, 0x03, 0xFE, 0xFE, 0x03, 0x25, 0x25, 0x25, 0x25, 0x05, 0xFE, 
};

uint8_t _16x16_memo[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//  ############## 
	// ##            ##
	// #              #
	// #              #
	// ################
	// #              #
	// #              #
	// # ###########  #
	// #              #
	// #              #
	// # #########    #
	// #           ####
	// #          #   #
	// # ######## #   #
	// ##         #  ##
	//  ############## 
	0x7F, 0xC8, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x88, 0xC8, 0x7F, 
	0xFE, 0x03, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x21, 0x0F, 0x11, 0x11, 0x13, 0xFE, 
};

uint8_t _16x16_volume[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//     ########    
	//    ##      ##   
	//   ##    #   ##  
	//  ##    ## #  ## 
	// ##    ### ##  ##
	// #    ## #  ##  #
	// # ####  #   #  #
	// # # #   # # #  #
	// # # #   # # #  #
	// # ####  #   #  #
	// #    ## #  ##  #
	// ##    ### ##  ##
	//  ##    ## #  ## 
	//   ##    #   ##  
	//    ##      ##   
	//     ########    
	0x0F, 0x18, 0x33, 0x62, 0xC3, 0x86, 0x8C, 0x98, 0xBF, 0x80, 0x99, 0xCC, 0x67, 0x30, 0x18, 0x0F, 
	0xF0, 0x18, 0xCC, 0x46, 0xC3, 0x61, 0x31, 0x19, 0xFD, 0x01, 0x99, 0x33, 0xE6, 0x0C, 0x18, 0xF0, 
};

uint8_t _16x16_clock[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//      ######     
	//    ##########   
	//   ###   #  ###  
	//  ###    #   ### 
	//  ##     #  # ## 
	// ##      # #   ##
	// ##      ##    ##
	// ##     ##     ##
	// ##     ##     ##
	// ##            ##
	// ##            ##
	//  ##          ## 
	//  ###        ### 
	//   ###      ###  
	//    ##########   
	//      ######     
	0x07, 0x1F, 0x38, 0x70, 0x60, 0xC0, 0xC0, 0xC1, 0xFF, 0xC2, 0xC4, 0x68, 0x70, 0x38, 0x1F, 0x07, 
	0xE0, 0xF8, 0x1C, 0x0E, 0x06, 0x03, 0x03, 0x83, 0x83, 0x03, 0x03, 0x06, 0x0E, 0x1C, 0xF8, 0xE0, 
};
  
uint8_t _16x16_no[] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
 	//      ######     
	//    ##########   
	//   ###     ####  
	//  ###       #### 
	//  ##       ##### 
	// ##       ### ###
	// ##      ###   ##
	// ##     ###    ##
	// ##    ###     ##
	// ##   ###      ##
	// ### ###       ##
	//  #####       ## 
	//  ####       ### 
	//   ####     ###  
	//    ##########   
	//      ######     
	
	0x07, 0x1F, 0x38, 0x70, 0x60, 0xC0, 0xC0, 0xC1, 0xC3, 0xC7, 0xEE, 0x7C, 0x78, 0x3C, 0x1F, 0x07, 
	0xE0, 0xF8, 0x3C, 0x1E, 0x3E, 0x77, 0xE3, 0xC3, 0x83, 0x03, 0x03, 0x06, 0x0E, 0x1C, 0xF8, 0xE0, 
}; 
uint8_t _16x16_exclamation [] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
/* 
**  Font data for Webdings 16pt
*/	

	/* @0 'i' (16 pixels wide) */
	//      ######     
	//    ###    ###   
	//   ###  ##  ###  
	//  ###   ##   ### 
	//  ##    ##    ## 
	// ##            ##
	// ##     ##     ##
	// ##     ##     ##
	// ##     ##     ##
	// ##     ##     ##
	// ##     ##     ##
	//  ##    ##    ## 
	//  ###   ##   ### 
	//   ###  ##  ###  
	//    ###    ###   
	//      ######     
	0x07, 0x1F, 0x38, 0x70, 0x60, 0xC0, 0x80, 0xBB, 0xBB, 0x80, 0xC0, 0x60, 0x70, 0x38, 0x1F, 0x07, 
	0xE0, 0xF8, 0x1C, 0x0E, 0x06, 0x03, 0x01, 0xFD, 0xFD, 0x01, 0x03, 0x06, 0x0E, 0x1C, 0xF8, 0xE0, 
};  

uint8_t _16x16_satellite [] PROGMEM =
{
  0x00,0x10,   //width  : 16
  0x00,0x10,   //Height : 16
	//        ######   
	//              #  
	//         ####  # 
	//             #  #
	//          ##  # #
	//  ##        # # #
	// ####    ## # # #
	// #  ##   ##   # #
	// #   ## #     # #
	// #    ##        #
	// ##    ##        
	// # #    ##       
	// ## #    ##      
	//  ## #    ##     
	//   ## #   ##     
	//    #######      
	0x03, 0x06, 0x06, 0x03, 0x01, 0x00, 0x00, 0x80, 0xA3, 0xAB, 0xA8, 0xA6, 0x90, 0x4F, 0x20, 0x1F, 
	0xF8, 0x2C, 0x16, 0x0B, 0x85, 0xC3, 0x61, 0xB1, 0x19, 0x0F, 0x06, 0x00, 0x00, 0x80, 0x00, 0xC0, 
};

uint8_t _17x16_ohm [] PROGMEM =
{
  0x00,0x11,   //width  : 17
  0x00,0x10,   //Height : 16
/* 
**  Font data for Symbol 18pt
*/

	/* @0 'W' (17 pixels wide) */
	//      #######     
	//    ###     ###   
	//   ###       ###  
	//  ###         ### 
	// ###           ###
	// ###           ###
	// ###           ###
	// ###           ###
	// ###           ###
	//  ###          ## 
	//  ###         ### 
	//   ###       ###  
	//     ###   ####   
	// ##    ## ##    ##
	// ######## ########
	// ######## ########
	0x0F, 0x1F, 0x3F, 0x70, 0x60, 0xC0, 0x80, 0x80, 0x80, 0x80, 0x80, 0xC0, 0x60, 0x70, 0x3F, 0x1F, 0x0F, 
	0x87, 0xE7, 0xF3, 0x73, 0x1B, 0x0B, 0x0F, 0x07, 0x00, 0x07, 0x0F, 0x0B, 0x1B, 0x3B, 0xF3, 0xE7, 0x87, 
};

uint8_t _17x16_volt[] PROGMEM =
{
  0x00,0x11,   //width  : 17
  0x00,0x10,   //Height : 16
/* 
**  Font data for Webdings 16pt
*/
	/* @32 '~' (17 pixels wide) */
	//                 #
	//                # 
	//               #  
	//        #     ##  
	//        ##   ##   
	//       ###  ###   
	//       #######    
	//      #######     
	//     ########     
	//     ### ###      
	//    ###  ###      
	//    ##    #       
	//   ##     #       
	//  ##              
	//  #               
	// #                
	0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0x1F, 0x0F, 0x03, 0x03, 0x07, 0x0E, 0x1C, 0x30, 0x40, 0x80, 
	0x01, 0x06, 0x0C, 0x38, 0xF0, 0xE0, 0xC0, 0x80, 0xE0, 0xF8, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
};

uint8_t _27x32_android[] PROGMEM =
{
  0x00,0x1b,   //width  : 27
  0x00,0x20,   //Height : 32	
	
	
	
	//         ##       ##        
	//         ###     ###        
	//          #########         
	//        #############       
	//       ####  ###  ####      
	//      #####  ###  #####     
	//      #################     
	//      #               #     
	//                            
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #### ################# ####
	// #  # ################# #  #
	//      #################     
	//      #################     
	//      #################     
	//      # ###### ###### #     
	//         ####   ####        
	//         ####   ####        
	//         ####   ####        
	//         ####   ####        
	//         ####   ####        
	//         #  #   #  #        
	0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x0E, 0x1E, 0xDE, 0xFE,	0x72, 0x32, 0x3E, 0x3E, 0x3E, 0x32, 0x72, 0xFE, 0xDE, 0x1E,	0x0E, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x7F, 0x7F, 0x7F, 0x7F, 0x00, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x00, 0x7F, 0x7F, 0x7F, 0x7F, 
	0xF0, 0xE0, 0xE0, 0xF0, 0x00, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF, 0x00, 0xF0, 0xE0, 0xE0, 0xF0, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0xF8, 0xF8, 0xFC, 0x00, 0x00, 0x00, 0xFC, 0xF8, 0xF8, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
};

  
/*
 * EOF
 */