/*
 * $Id: ds3232.c 2011-12-27 12:28 ssk. $
 *
 * This file is part of AvrTherm.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Copyright (C) 2012 ssk. <kim.boricha@gmail.com>
 */

#include <avr/io.h>
#include <util/delay.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "i2cmaster.h"
#include "ds3232.h"

timedate td;             // Time - date structure
//static void DS3232_read(uint8_t address,uint8_t *data);
static void DS3232_write(uint8_t address,uint8_t data);
static void ds3232_setdate(void);
static void ds3232_settime(void);
static uint8_t dec2bcd(uint8_t num);
static uint8_t bcd2dec(uint8_t num);
//extern void beep(void);


void ds3232_init(void)
{
  // Write in register 'Control' 01000000
  // Configurar el pin INT/SQW para que saque una onda cuadrada de 1 Hz,
  // incluso si el DS3232 se alimenta de la bateria. Dejar sin habilitar
  // las interrupciones de las alarmas.
  DS3232_write(DS3232_CTRL_REGISTER, 0x00);      // Write in register 'Control' 01000000


  // Write in register 'Control/Status'
  //BIT:   7     6      5      4       3     2   1   0
  //NAME: OSF BB32kHz CRATE1 CRATE0 EN32kHz BSY A2F A1F
  //POR*:  1     1      0      0       1     0   0   0
  //0x30:  0     0      1      1       0     0   0   0
  //0x38:  0     0      1      1       1     0   0   0
  //POR is defined as the first application of power to the device, either VBAT or VCC.
  DS3232_write(DS3232_CTRL_STATUS_REGISTER, 0x38);

  // No anadir ni sustraer nada a los valores que el DS3232 autocalcula
  // para calibrar los capacitores de su oscilador.

  DS3232_write(DS3232_AGING_OFFSET, 0x00);    //Write in register registro 'Aging Offset' 00000000

 //Time Set
//ds3232_settime();
//ds3232_setdate();

}

// Function to write to RTC
static void DS3232_write(uint8_t address,uint8_t data)
{
  i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);    // Issue start on I2C bus in write mode
  i2c_write(address);                           // send the address of data to write
  i2c_write(data);                              // send the data
  i2c_stop();                                   // Issue a stop on I2C bus
}

// Function to read RTC
//static void DS3232_read(uint8_t address,uint8_t *data)
//{
//  i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);    // Issue start on I2C bus in write mode
//  i2c_write(address);                           // send the address of data to read
//  i2c_rep_start(DS3232_I2C_ADDR+I2C_READ);      //Re-issue Start but read this time
//  *data = i2c_readNak();                        // read byte
//  i2c_stop();                                   // Issue a stop on I2C bus
//}


// Convert Decimal to Binary Coded Decimal (BCD)
static uint8_t dec2bcd(uint8_t num)
{
  return (((num/10) << 4) | (num % 10));
}

// Convert Binary Coded Decimal (BCD) to Decimal
static uint8_t bcd2dec(uint8_t num)
{
  return (((num>>4) * 10) + (num & 0x0F));
}
static void ds3232_settime(void)
{
	uint8_t hour;
  i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);
  i2c_write(DS3232_TIME_START_ADDR);

  // AM 01:01:00
  i2c_write(dec2bcd(0));          // seconds
  i2c_write(dec2bcd(35));         // minutes

  hour =     dec2bcd(0);          // 1                    1-digit
  
  hour |=   _BV(4);               // 1:  (Hour > 9 )     10-digit
//hour &= ~(_BV(4));              // 0:  (Hour < 10)     10-digit

  hour |=   _BV(5);               // 1:PM
//hour &= ~(_BV(5));              // 0:AM

//hour &= ~(_BV(6));              // 0:24 Mode
  hour |=   _BV(6);               // 1:12 Mode

  i2c_write(hour);

  //ADDRESS  7   6        5      4   3 2 1 0
  //    02h  0 12/!24  !AM/PM 10Hour H o u r
  //                   20Hour
  //+------------------------------------------
  // ex)PM 11
  //
  //24Hour   0   0      1(20)    0    0 0 1 1 (3)  -> 0x23(35)
  //12Hour   0   1      1(PM)    1(1) 0 0 0 1 (1)  -> 0x71(113)
  i2c_stop();
}

static void ds3232_setdate(void)
{
   i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);
   i2c_write(DS3232_DATE_START_ADDR);

   i2c_write(dec2bcd(1));    // Day (Sun=1,Mon=2,Tue=3,Wed=4,Thu=5,Fri=6,Sat=7)
   i2c_write(dec2bcd(13));    // Date
   i2c_write(dec2bcd(10));   // Month
   i2c_write(dec2bcd(13));   // Year    '13'

   i2c_stop();
}

void ds3232_gettime(timedate* tm)
{
	uint8_t hour;

  i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);
  i2c_write(DS3232_TIME_START_ADDR);
  i2c_rep_start(DS3232_I2C_ADDR+I2C_READ);

  tm->second = bcd2dec(i2c_readAck());
  tm->minute = bcd2dec(i2c_readAck());
  hour       =  i2c_readAck();
  tm->hour   = bcd2dec(hour & 0x1f);
  tm->wday   = bcd2dec(i2c_readAck());
  tm->day    = bcd2dec(i2c_readAck());
  tm->month  = bcd2dec(i2c_readAck());
  tm->year   = bcd2dec(i2c_readAck());

  i2c_readNak();
	i2c_stop();

  if((hour & 0x40)  &&  // 12 hour mode
   	 (hour & 0x20))     // PM
  {
  	tm->ampm[0] = 'P';
  	tm->ampm[1] = 'M';
  	tm->ampm[2] = '\0';
  }
  else
  {
  	tm->ampm[0] = 'A';
  	tm->ampm[1] = 'M';
  	tm->ampm[2] = '\0';
  }

  if(tm->minute == 59)
  {
     switch(tm->second)
     {
       case 57:
       case 58:
       case 59:
//           beep();
           break;

       default:
           break;
     }
  }
//else
//if((tm->minute  == 0) && (tm->second  == 0))
//{
//    beep();beep();
//}
}

uint16_t ds3232_gettemp(void)
{
	uint8_t msb=0;
	uint8_t lsb=0;

  i2c_start_wait(DS3232_I2C_ADDR+I2C_WRITE);
  i2c_write(DS3232_TEMP_START_ADDR);
  i2c_rep_start(DS3232_I2C_ADDR+I2C_READ);

  msb = i2c_readAck();
  lsb = i2c_readNak();
	i2c_stop();

  return (((uint16_t)msb << 8) + lsb);
}
