#ifndef DS3232_H_
#define DS3232_H_
/*
 * $Id: ds3232.h 4/8/2013 4:06:56 PM ssk. $
 *
 * This file is part of AvrTherm.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Copyright (C) 2012 ssk. <kim.boricha@gmail.com>
 */

/**
 * \file
 *
 * This file contains methods to access a DS3232 Real-time Clock Module (I2C Bus) over
 * an i2c bus. The device address is currently hardcoded in the implementation
 * file and supports only one DS3232 attached to the bus.
 */
#include <avr/io.h>
#include <inttypes.h>

#define DS3232_I2C_ADDR              0xd0
#define DS3232_REG_START_ADDR        0x00
#define DS3232_TIME_START_ADDR       0x00
#define DS3232_SECONDS_START_ADDR    0x00

#define DS3232_DATE_START_ADDR       0x03
#define DS3232_TEMP_START_ADDR       0x11
#define DS3232_CTRL_REGISTER         0x0e
#define DS3232_CTRL_STATUS_REGISTER  0x0f
#define DS3232_AGING_OFFSET          0x11
 
#ifndef DS3232_ITYPES 
#define DS3232_ITYPES 
typedef struct tmElements_t 
{
  uint8_t second;
  uint8_t minute;
  char    ampm[3];
  uint8_t hour;
  uint8_t wday;   // day of week, sunday is day 1
  uint8_t day;
  uint8_t month;
  uint8_t year;   // offset from 1970;
} timedate;
#endif

extern timedate td;             // Time - date structure
extern void ds3232_gettime(timedate* tm);
extern void ds3232_init(void);
extern uint16_t ds3232_gettemp(void);

#endif