#ifndef EEPROM_H_
#define EEPROM_H_
/*
 * $Id: eeprom.h 2013-02-25 16:25:49  ssk  $
 *
 * Atmels AVR MCUs library support for external I2C Serial EEPROMs
 * 
 * This Program is Designed for 512kb I2C Atmel(AT24C512), OnSemi(CAT24C512) EEPROMs
 * 
 * Copyright (C) 2013  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/
#define EEPROM_MESSAGE_UART_OUT      0       // 1: work output message redirect UART

// Change this to the address of your EEPROM 
// Density <= 512Kb(62KByte), 0xA0[1010] + A2[0.1] + A1[0.1] + A0[0.1]) 
// Density >  512Kb(62KByte), 0xA0[1010] + A2[0.1] + A1[0.1] + P0)     (P0:A Memory page address bit)

#define EEPROM_I2C_DEVICE           0xA0     // ATmel AK-1205DD 
//#define EEPROM_I2C_DEVICE            0xA0   // STMicroelectronics M24M01-R
//#define EEPROM_I2C_DEVICE            0xAC   // On-Semi CAT24C512

#define EEPROM_DENSITY              4        // 1024Kbit(1Mbit)  = 1,048,576bit = 131,072Byte(1,048,576/8bit) = 128Kbyte(131,072/1024Byte) 
                                             //  512Kbit         =   524,288bit =  65,536Byte(  524,288/8bit) =  64Kbyte( 65,536/1024Byte)  
                                             //  256Kbit         =   262,144bit =  32,768Byte(  262,144/8bit) =  32Kbyte( 32,768/1024Byte)
//                                           //    4Kbit         =      4,096it =     512Byte(    4,096/8bit)
                                            
                                            
#define EEPROM_PAGE_SIZE            16       // 256Byte Page write(1024Kb/128Kbyte EEPROM)
                                             // 128Byte Page write( 512Kb/ 64Kbyte EEPROM)
                                             //  64Byte Page write( 256Kb/ 32Kbyte EEPROM)
                                             //  16Byte Page write(   4Kb/0.5Kbyte EEPROM)
                                             
#define EEPROM_MEMORY_PAGE_BIT       1       // 128KByte(1Mbit) EEPROM Memory Page bit

// Error Code
#define EEPROM_RET_CODE              0x00
#define EEPROM_RET_SUCCESS           EEPROM_RET_CODE + 0
#define EEPROM_RET_WRITE_AH_FAIL     EEPROM_RET_CODE + 1   // Write High byte Address Fail
#define EEPROM_RET_WRITE_AL_FAIL     EEPROM_RET_CODE + 2   // Write Low byte Address Fail
#define EEPROM_RET_WRITE_FAIL        EEPROM_RET_CODE + 3   // Write data Fail
#define EEPROM_RET_I2C_START_FAIL    EEPROM_RET_CODE + 4
#define EEPROM_RET_I2C_REPSTART_FAIL EEPROM_RET_CODE + 5
#define EEPROM_RET_READ_FAIL         EEPROM_RET_CODE + 6
#define EEPROM_RET_START_FAIL        EEPROM_RET_CODE + 9

extern uint8_t i2c_eeprom_page_address_bitset(uint8_t device, uint32_t addr);
extern uint8_t i2c_eeprom_write(uint8_t device, uint32_t addr, uint8_t data);
extern uint8_t i2c_eeprom_write_page(uint8_t device, uint32_t addr, uint8_t *data, uint16_t size);
extern uint8_t i2c_eeprom_read(uint8_t device, uint32_t addr);
extern uint8_t i2c_eeprom_read_seq_start(uint8_t device, uint32_t addr);
extern uint8_t i2c_eeprom_read_seq(void);
extern void i2c_eeprom_read_seq_stop(void);
#endif
