#ifndef FONTS_H_
#define FONTS_H_
/*
 * $Id: fonts.h 2013-02-20 13:51:44 ssk $
 *
 * Atmels AVR MCUs library support for graphic LCDs
 *
 * Supports fonts that are defined in bit map tables in ../fonts/allfonts.h
 * The font tables in this file were derived from a conversion program called TDF(The Dot Factory)
 * by Eran Duchan, Israel
 *
 * This Program is Designed for EPSON SED1335F0A
 *
 * Copyright (C) 2012  ssk.
 *
 * Originally Adapted from
 *
 *    Eran Duchan, Israel <http://www.pavius.net/2009/07/the-dot-factory-an-lcd-font-and-image-generator/>
 *    Kaiserslautern, Germany <eversmith@heizung-thomas.de>
 *    Martin Thomas, Kaiserslautern, Germany <eversmith@heizung-thomas.de>
 *
 * Changed & added additional constants for gcc version 4.3.3 (WinAVR 20100110), improved speed and optimized code
 * You need to be selective about the information you receive instead of accepting it unconditionally.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/
/**
 * \What is Callback?
 *
 *  In computer programming, a callback is a piece of executable code that is passed as an argument to other code,
 *  which is expected to call back (execute) the argument at some convenient time
 *
 *  http://en.wikipedia.org/wiki/Callback_%28computer_programming%29
 *  http://blog.naver.com/mrw0119?Redirect=Log&logNo=70169229789
 *
 * \AVR GCC forum - Maximum size of PROGMEM array?
 *
 *  This is limitation of gcc, but even if gcc would be fixed for this,
 *  the AVR's limitation for PROGMEM (accessed by LPM) is 64kB
 *
 *  http://www.avrfreaks.net/index.php?name=PNphpBB2&file=printview&t=80105
 *
 *  you must use ELPM, ie. the pgm_read_xxx_far functions, and/or the functions provided by the library of Carlos Lamas
 *  http://savannah.nongnu.org/patch/?6352
 *
 *  http://www.avrfreaks.net/index.php?name=PNphpBB2&file=viewtopic&p=599080
 *
 * \ssk
*/
#include <avr/pgmspace.h>

// Font Configuration
#define FONT_EXTERNAL_EEPROM        1          // 1:External EEPROM,0:Internal Flash,
#define FONT_HANGUL                 1          // 1:Hangul are used in this program
#define FONT_ENGLISH                0          // English Font, vfd_selectfont()
#define FONT_NO_WORD_WRAP           0          // 0:Word wrap
#define MAX(a,b) (((a)>(b))?(a):(b))
#define ks2kssm(high, low)       (((high)-0xb0)*(0xff-0xa1)+((low)-0xa1))

// Font Indices
#define FONT_SIZE                   0          // byte
#define FONT_FIXED_WIDTH            2          // pixel
#define FONT_HEIGHT                 3          // pixel
#define FONT_FIRST_CHAR             4
#define FONT_END_CHAR               5
#define FONT_WIDTH_TABLE            6          // bytes

#define KFONT_SPACE_BTL             0          // Hangul space between the lines
#define KFONT_HEADER_SZ             4          // Hangul font header size
#define KFONT_CNV_HEADER_SZ         2          // Hangul code converter index table header size

#if(FONT_EXTERNAL_EEPROM)
   #warning "EXTERNAL EEPROM FONT Installed!!!."
   #define  arial_narrow_8_x12     0x0
   #define  arial_narrow_9_x12b    0x366
   #define  arial_narrow_12_x16    0x760
   #define  arial_narrow_13_x16b   0xBDA
   #define  arial_narrow_18_x23b   0x1104
   #define  arial_narrow_18_x24    0x1BA8
   #define  arial_narrow_24_x31b   0x25C2
   #define  arial_narrow_25_x32    0x388C
   #define  arial_narrow_31_x39b   0x4A46
   #define  corsiva_13_x16         0x6816
   #define  corsiva_18_x23         0x6E3E
   #define  digitalnums_14_10x16   0x7AC8     // Fidex width
   #define  digitalnums_22_16x24   0x7C73     // Fidex width
   #define  digitalnums_29_21x32   0x806A     // Fidex width
   #define  digitalnums_37_26x40   0x8755     // Fidex width
   #define  digitalnums_43_31x48   0x9206     // Fidex width
   #define  fixednums_13_7x15      0xA14F     // Fidex width
   #define  fixednums_21_12x24     0xA27C     // Fidex width
   #define  fixednums_27_16x32     0xA577     // Fidex width
   #define  fixednums_34_20x39     0xAABE     // Fidex width
   #define  fixednums_40_22x47     0xB2F9     // Fidex width
   #define  system_5_5x7           0xBDD4     // Fidex width
   #define  ks2kssm_index          0xBFB6     // Hangul Code Table
   #define  TBG1_FNT_16X16         0xDB43     // Fidex width
   #define  TBG2_FNT_16X16         0x10848    // Fidex width
   #define  TB24G_FNT_24X24        0x1354D    // Fidex width
   #define  TB24M_FNT_24X24        0x19A92    // Fidex width
#else

/*
* Internall Flash memory
* Select desired fonts. (Simply comment out those not needed)
*/
/////#define FONT_ARIAL_NARROW_8_X12
     #define FONT_ARIAL_NARROW_9_X12B
/////#define FONT_ARIAL_NARROW_12_X16
/////#define FONT_ARIAL_NARROW_13_X16B
/////#define FONT_ARIAL_NARROW_18_X23B
/////#define FONT_ARIAL_NARROW_18_X24
/////#define FONT_ARIAL_NARROW_24_X31B
/////#define FONT_ARIAL_NARROW_25_X32
/////#define FONT_ARIAL_NARROW_31_X39B
/////#define FONT_FIXEDNUMS_13_7X15
/////#define FONT_FIXEDNUMS_21_12X24
/////#define FONT_FIXEDNUMS_27_16X32
/////#define FONT_FIXEDNUMS_34_20X39
/////#define FONT_FIXEDNUMS_40_22X47
/////#define FONT_DIGITALNUMS_14_10X16
/////#define FONT_DIGITALNUMS_22_16X24
/////#define FONT_DIGITALNUMS_29_21X32
/////#define FONT_DIGITALNUMS_37_26X40
/////#define FONT_DIGITALNUMS_43_31X48
/////#define FONT_CORSIVA_13_X16
/////#define FONT_CORSIVA_18_X23
     #define FONT_SYSTEM_5_5X7

   #if(FONT_HANGUL)
/////#define FONT_KS2KSSM_INDEX     // KS, KSSM ڵ庯ȯ index table
/////#define FONT_TBG1_FNT_16X16    // ¹ѱ 1.5 ü(ü)
/////#define FONT_TBG2_FNT_16X16    // ¹ѱ 1.5 ü(ü)
/////#define FONT_TBHM_HAN_16X16    // ¹ѱ ƹü
/////#define FONT_TB24G_FNT_24X24   // ¹ѱ 24x24 ü(ü)
/////#define FONT_TB24M_FNT_24X24   // ¹ѱ 24x24 ü(ü)
   #endif
#endif

#ifdef FONT_ARIAL_NARROW_8_X12
  extern uint8_t arial_narrow_8_x12[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_9_X12B
  extern uint8_t arial_narrow_9_x12b[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_13_X16B
  extern uint8_t arial_narrow_13_x16b[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_12_X16
  extern uint8_t arial_narrow_12_x16[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_18_X23B
  extern uint8_t arial_narrow_18_x23b[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_18_X24
  extern uint8_t arial_narrow_18_x24[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_24_X31B
  extern uint8_t arial_narrow_24_x31b[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_25_X32
  extern uint8_t arial_narrow_25_x32[] PROGMEM;
#endif

#ifdef FONT_ARIAL_NARROW_31_X39B
  extern uint8_t arial_narrow_31_x39b[] PROGMEM;
#endif

#ifdef FONT_FIXEDNUMS_13_7X15
  extern uint8_t fixednums_13_7x15[] PROGMEM;
#endif

#ifdef FONT_FIXEDNUMS_21_12X24
  extern uint8_t fixednums_21_12x24[] PROGMEM;
#endif

#ifdef FONT_FIXEDNUMS_27_16X32
  extern uint8_t fixednums_27_16x32[] PROGMEM;
#endif

#ifdef FONT_FIXEDNUMS_34_20X39
  extern uint8_t fixednums_34_20x39[] PROGMEM;
#endif

#ifdef FONT_FIXEDNUMS_40_22X47
  extern uint8_t fixednums_40_22x47[] PROGMEM;
#endif

#ifdef FONT_DIGITALNUMS_14_10X16
  extern uint8_t digitalnums_14_10x16[] PROGMEM;
#endif

#ifdef FONT_DIGITALNUMS_22_16X24
  extern uint8_t digitalnums_22_16x24[] PROGMEM;
#endif

#ifdef FONT_DIGITALNUMS_29_21X32
  extern uint8_t digitalnums_29_21x32[] PROGMEM;
#endif

#ifdef FONT_DIGITALNUMS_37_26X40
  extern uint8_t digitalnums_37_26x40[] PROGMEM;
#endif

#ifdef FONT_DIGITALNUMS_43_31X48
  extern uint8_t digitalnums_43_31x48[] PROGMEM;
#endif

#ifdef FONT_SYSTEM_5_5X7
  extern uint8_t system_5_5x7[] PROGMEM;
#endif

#ifdef FONT_CORSIVA_13_X16
  extern uint8_t corsiva_13_x16[] PROGMEM;
#endif

#ifdef FONT_CORSIVA_18_X23
  extern uint8_t corsiva_18_x23[] PROGMEM;
#endif

// Hangul
#ifdef FONT_KS2KSSM_INDEX
  extern uint8_t ks2kssm_index[] PROGMEM;
#endif

#ifdef FONT_TBG1_FNT_16X16
  extern uint8_t TBG1_FNT_16X16[] PROGMEM;
#endif

#ifdef FONT_TBG2_FNT_16X16
  extern uint8_t TBG2_FNT_16X16[] PROGMEM;
#endif

#ifdef FONT_TBHM_HAN_16X16
  extern uint8_t TBHM_HAN_16X16[] PROGMEM;
#endif

#ifdef FONT_TB24G_FNT_24X24
  extern uint8_t TB24G_FNT_24X24[] PROGMEM;
#endif

#ifdef FONT_TB24M_FNT_24X24
  extern uint8_t TB24M_FNT_24X24[] PROGMEM;
#endif

#if(FONT_EXTERNAL_EEPROM)
  #line 0 "EXTERNAL EEPROM FONT Installed!!!."
  // define a pointer to a function which receives uint8_t*
  typedef uint8_t (*vfd_font_callback)(const uint32_t);

  extern  void vfd_selectfont(uint32_t font, uint8_t color, uint8_t type, int8_t sbl);
  extern  uint8_t    vfd_readfont(const uint32_t addr);
  extern  uint32_t  _vfd_font;
  extern  uint32_t  _vfd_Kfont;
#else
  // define a pointer to a function which receives uint8_t*
  typedef uint8_t (*vfd_font_callback)(const uint8_t*);

  extern  void vfd_selectfont(uint8_t* font, uint8_t color, uint8_t type, int8_t sbl);
  extern  uint8_t   vfd_readfont(const uint8_t* ptr);
  extern  uint8_t* _vfd_font;
  extern  uint8_t* _vfd_Kfont;
#endif

extern vfd_font_callback  _vfd_fontread;   // point to _vfd_fontread function
extern uint8_t  _vfd_fontcolor;
extern  int8_t  _vfd_sbl;                  // space between letters;
extern void vfd_putcK(uint16_t kc);        // hangul putc
//extern void vfd_puts(const unsigned char *str);
extern void vfd_puts(const char *str);
extern void vfd_puts_p(PGM_P str);
extern void vfd_putc(uint8_t c);

/**
 @brief    convert unsigned long int to characters in LCD
 @param    value unsigned long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void vfd_puts_ultoa(uint32_t value, uint8_t radix, uint8_t length, uint8_t leadingchar);

/**
 @brief    convert signed long int to characters in LCD
 @param    value signed long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void vfd_puts_ltoa (int32_t value, uint8_t radix, uint8_t length, uint8_t leadingchar);

#define vfd_puts_P(__s) vfd_puts_p(PSTR(__s))
#define isfixedwidth(font)  (_vfd_fontread(font+FONT_FIXED_WIDTH) > 0)
#endif
/*
 * EOF
 */
