/*
 * $Id: uart.h 2012-10-24 6:00  ssk  $
 *
 * This file is part of DALLAS DS1721 Temperature Sensor Tutorial.
 *
 * Copyright (C) 2012  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef UART_H
#define UART_H

#define MAX_UART_CHANNEL 1     // UARTChannel No. (0..1)
#define UART_0           0     // UART 0
#define UART_1           1     // UART 1

/**
 * \file
 * Functions for accessing the UART in polling mode
 */

#include <avr/pgmspace.h>

extern void uart_init(uint8_t channel, uint16_t baudrate);  // Initialize the uart in polling mode
extern void uart_putc(uint8_t channel, uint8_t data);           // Send one byte over the uart
extern void uart_puts(uint8_t channel, const char *str);        // Send a string over the uart
/**
 @brief    convert unsigned long int to characters in UART
 @param    value unsigned long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void uart_puts_ultoa(uint8_t channel, uint32_t value, uint8_t radix, uint8_t length, uint8_t leadingchar);

/**
 @brief    convert signed long int to characters in UART
 @param    value signed long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void uart_puts_ltoa(uint8_t channel, int32_t value, uint8_t radix, uint8_t length, uint8_t leadingchar);

extern uint8_t uart_getc(uint8_t channel);                // Receive one byte from the uart
extern void uart_puts_p(uint8_t channel, const char *progmem_s);// Send a string from program memory over the uart

// macros for automatically storing string constant in program memory
#define uart_puts_P(__n, __s)    uart_puts_p(__n, PSTR(__s))
#endif
